@@ -6,8 +6,9 @@ from typing import Any
 import platform
 
 from psiconfig import TomlConfig
-from psiutils._logger import logger
 import psiutils.text as txt
+from psiutils._logger import logger
+
 
 DEFAULT_GEOMETRY = '500x400'
 
@@ -72,13 +73,6 @@ def enable_frame(parent: tk.Frame, enable: bool = True) -> None:
         else:
             child.configure(state=state)
 
-
-# def geometry(geometry: dict, form: str = '') -> str:
-#     system = platform.system()
-#     if system not in ['Linux', 'Windows']:
-#         system = 'Linux'
-#     return geometry[Path(form).stem][system]
-
 def geometry(config: TomlConfig, file: Path, default: str = '') -> str:
     if not default:
         default = DEFAULT_GEOMETRY
@@ -94,7 +88,7 @@ def window_resize(master: tk.Tk, file: str, *args) -> None:
         f'{master.root.winfo_width()}x{master.root.winfo_height()}+'
         f'{master.root.winfo_x()}+{match[2]}')
     master.config.read()
-    geometry = master.config.geometry
-    geometry[Path(file).stem] = window_geometry
-    master.config.update('geometry', geometry)
+    new_geometry = master.config.geometry
+    new_geometry[Path(file).stem] = window_geometry
+    master.config.update('geometry', new_geometry)
     master.config.save()
